pragma solidity ^0.4.24;

import "openzeppelin-solidity/contracts/token/ERC721/ERC721Token.sol";
import "openzeppelin-solidity/contracts/ownership/Ownable.sol";
import "openzeppelin-solidity/contracts/lifecycle/Pausable.sol";

contract SupervisedToken is ERC721Token, Ownable, Pausable {

    address supervisor;
    uint256 complianceProviderId;

    constructor(
        string _name,
        string _symbol,
        address _supervisor,
        address _owner
    ) ERC721Token(_name, _symbol) public
    {
        setSupervisor(_supervisor);
        _transferOwnership(_owner);
    }

    modifier onlyAdmin {
        require(msg.sender == owner || msg.sender == supervisor);
        _;
    }

    /**
     * @dev Mints a token to an address.
     * @param _to address of the future owner of the token
     * @return tokenId token ID of new token
     */
    function mintTo(address _to) public onlyAdmin returns (uint256 tokenId) {
        tokenId = totalSupply().add(1);
        _mint(_to, tokenId);
    }

    /**
     * @dev Sets token metadata URI.
     * @param _tokenId token ID
     * @param _tokenURI token URI for the token
     */
    function setTokenURI( uint256 _tokenId, string _tokenURI) public onlyAdmin {
        _setTokenURI(_tokenId, _tokenURI);
    }

    /**
     * @dev Set Supervisor
     * @param _supervisor Supervisor address
     */
    function setSupervisor(address _supervisor) public onlyAdmin {
        supervisor = _supervisor;
    }

    /**
     * @dev Set Compliance Provider
     * @param _providerId Abacus provider ID
     */
    function setComplianceProvider(uint256 _providerId) public onlyAdmin {
        complianceProviderId = _providerId;
    }

    /**
     * @dev Prevent transfers
     */
    function transferFrom(address _from, address _to, uint256 _tokenId) public {
        revert();
    }

    function safeTransferFrom(address _from, address _to, uint256 _tokenId) public {
        revert();
    }

    function safeTransferFrom(address _from, address _to, uint256 _tokenId, bytes data) public {
        revert();
    }

}